# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v2/proto/resources/media_file.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.ads.google_ads.v2.proto.enums import media_type_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_media__type__pb2
from google.ads.google_ads.v2.proto.enums import mime_type_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_mime__type__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v2/proto/resources/media_file.proto',
  package='google.ads.googleads.v2.resources',
  syntax='proto3',
  serialized_options=_b('\n%com.google.ads.googleads.v2.resourcesB\016MediaFileProtoP\001ZJgoogle.golang.org/genproto/googleapis/ads/googleads/v2/resources;resources\242\002\003GAA\252\002!Google.Ads.GoogleAds.V2.Resources\312\002!Google\\Ads\\GoogleAds\\V2\\Resources\352\002%Google::Ads::GoogleAds::V2::Resources'),
  serialized_pb=_b('\n8google/ads/googleads_v2/proto/resources/media_file.proto\x12!google.ads.googleads.v2.resources\x1a\x34google/ads/googleads_v2/proto/enums/media_type.proto\x1a\x33google/ads/googleads_v2/proto/enums/mime_type.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1cgoogle/api/annotations.proto\"\xfd\x04\n\tMediaFile\x12\x15\n\rresource_name\x18\x01 \x01(\t\x12\'\n\x02id\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x44\n\x04type\x18\x05 \x01(\x0e\x32\x36.google.ads.googleads.v2.enums.MediaTypeEnum.MediaType\x12G\n\tmime_type\x18\x06 \x01(\x0e\x32\x34.google.ads.googleads.v2.enums.MimeTypeEnum.MimeType\x12\x30\n\nsource_url\x18\x07 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12*\n\x04name\x18\x08 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12.\n\tfile_size\x18\t \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12>\n\x05image\x18\x03 \x01(\x0b\x32-.google.ads.googleads.v2.resources.MediaImageH\x00\x12\x46\n\x0cmedia_bundle\x18\x04 \x01(\x0b\x32..google.ads.googleads.v2.resources.MediaBundleH\x00\x12>\n\x05\x61udio\x18\n \x01(\x0b\x32-.google.ads.googleads.v2.resources.MediaAudioH\x00\x12>\n\x05video\x18\x0b \x01(\x0b\x32-.google.ads.googleads.v2.resources.MediaVideoH\x00\x42\x0b\n\tmediatype\"7\n\nMediaImage\x12)\n\x04\x64\x61ta\x18\x01 \x01(\x0b\x32\x1b.google.protobuf.BytesValue\"8\n\x0bMediaBundle\x12)\n\x04\x64\x61ta\x18\x01 \x01(\x0b\x32\x1b.google.protobuf.BytesValue\"E\n\nMediaAudio\x12\x37\n\x12\x61\x64_duration_millis\x18\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\"\xe9\x01\n\nMediaVideo\x12\x37\n\x12\x61\x64_duration_millis\x18\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x36\n\x10youtube_video_id\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x39\n\x13\x61\x64vertising_id_code\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12/\n\tisci_code\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.StringValueB\xfb\x01\n%com.google.ads.googleads.v2.resourcesB\x0eMediaFileProtoP\x01ZJgoogle.golang.org/genproto/googleapis/ads/googleads/v2/resources;resources\xa2\x02\x03GAA\xaa\x02!Google.Ads.GoogleAds.V2.Resources\xca\x02!Google\\Ads\\GoogleAds\\V2\\Resources\xea\x02%Google::Ads::GoogleAds::V2::Resourcesb\x06proto3')
  ,
  dependencies=[google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_media__type__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_mime__type__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,])




_MEDIAFILE = _descriptor.Descriptor(
  name='MediaFile',
  full_name='google.ads.googleads.v2.resources.MediaFile',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_name', full_name='google.ads.googleads.v2.resources.MediaFile.resource_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='id', full_name='google.ads.googleads.v2.resources.MediaFile.id', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='type', full_name='google.ads.googleads.v2.resources.MediaFile.type', index=2,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mime_type', full_name='google.ads.googleads.v2.resources.MediaFile.mime_type', index=3,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='source_url', full_name='google.ads.googleads.v2.resources.MediaFile.source_url', index=4,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='google.ads.googleads.v2.resources.MediaFile.name', index=5,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='file_size', full_name='google.ads.googleads.v2.resources.MediaFile.file_size', index=6,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='image', full_name='google.ads.googleads.v2.resources.MediaFile.image', index=7,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='media_bundle', full_name='google.ads.googleads.v2.resources.MediaFile.media_bundle', index=8,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='audio', full_name='google.ads.googleads.v2.resources.MediaFile.audio', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='video', full_name='google.ads.googleads.v2.resources.MediaFile.video', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='mediatype', full_name='google.ads.googleads.v2.resources.MediaFile.mediatype',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=265,
  serialized_end=902,
)


_MEDIAIMAGE = _descriptor.Descriptor(
  name='MediaImage',
  full_name='google.ads.googleads.v2.resources.MediaImage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='google.ads.googleads.v2.resources.MediaImage.data', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=904,
  serialized_end=959,
)


_MEDIABUNDLE = _descriptor.Descriptor(
  name='MediaBundle',
  full_name='google.ads.googleads.v2.resources.MediaBundle',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='google.ads.googleads.v2.resources.MediaBundle.data', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=961,
  serialized_end=1017,
)


_MEDIAAUDIO = _descriptor.Descriptor(
  name='MediaAudio',
  full_name='google.ads.googleads.v2.resources.MediaAudio',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='ad_duration_millis', full_name='google.ads.googleads.v2.resources.MediaAudio.ad_duration_millis', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1019,
  serialized_end=1088,
)


_MEDIAVIDEO = _descriptor.Descriptor(
  name='MediaVideo',
  full_name='google.ads.googleads.v2.resources.MediaVideo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='ad_duration_millis', full_name='google.ads.googleads.v2.resources.MediaVideo.ad_duration_millis', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='youtube_video_id', full_name='google.ads.googleads.v2.resources.MediaVideo.youtube_video_id', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='advertising_id_code', full_name='google.ads.googleads.v2.resources.MediaVideo.advertising_id_code', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='isci_code', full_name='google.ads.googleads.v2.resources.MediaVideo.isci_code', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1091,
  serialized_end=1324,
)

_MEDIAFILE.fields_by_name['id'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_MEDIAFILE.fields_by_name['type'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_media__type__pb2._MEDIATYPEENUM_MEDIATYPE
_MEDIAFILE.fields_by_name['mime_type'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_mime__type__pb2._MIMETYPEENUM_MIMETYPE
_MEDIAFILE.fields_by_name['source_url'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_MEDIAFILE.fields_by_name['name'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_MEDIAFILE.fields_by_name['file_size'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_MEDIAFILE.fields_by_name['image'].message_type = _MEDIAIMAGE
_MEDIAFILE.fields_by_name['media_bundle'].message_type = _MEDIABUNDLE
_MEDIAFILE.fields_by_name['audio'].message_type = _MEDIAAUDIO
_MEDIAFILE.fields_by_name['video'].message_type = _MEDIAVIDEO
_MEDIAFILE.oneofs_by_name['mediatype'].fields.append(
  _MEDIAFILE.fields_by_name['image'])
_MEDIAFILE.fields_by_name['image'].containing_oneof = _MEDIAFILE.oneofs_by_name['mediatype']
_MEDIAFILE.oneofs_by_name['mediatype'].fields.append(
  _MEDIAFILE.fields_by_name['media_bundle'])
_MEDIAFILE.fields_by_name['media_bundle'].containing_oneof = _MEDIAFILE.oneofs_by_name['mediatype']
_MEDIAFILE.oneofs_by_name['mediatype'].fields.append(
  _MEDIAFILE.fields_by_name['audio'])
_MEDIAFILE.fields_by_name['audio'].containing_oneof = _MEDIAFILE.oneofs_by_name['mediatype']
_MEDIAFILE.oneofs_by_name['mediatype'].fields.append(
  _MEDIAFILE.fields_by_name['video'])
_MEDIAFILE.fields_by_name['video'].containing_oneof = _MEDIAFILE.oneofs_by_name['mediatype']
_MEDIAIMAGE.fields_by_name['data'].message_type = google_dot_protobuf_dot_wrappers__pb2._BYTESVALUE
_MEDIABUNDLE.fields_by_name['data'].message_type = google_dot_protobuf_dot_wrappers__pb2._BYTESVALUE
_MEDIAAUDIO.fields_by_name['ad_duration_millis'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_MEDIAVIDEO.fields_by_name['ad_duration_millis'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_MEDIAVIDEO.fields_by_name['youtube_video_id'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_MEDIAVIDEO.fields_by_name['advertising_id_code'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_MEDIAVIDEO.fields_by_name['isci_code'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
DESCRIPTOR.message_types_by_name['MediaFile'] = _MEDIAFILE
DESCRIPTOR.message_types_by_name['MediaImage'] = _MEDIAIMAGE
DESCRIPTOR.message_types_by_name['MediaBundle'] = _MEDIABUNDLE
DESCRIPTOR.message_types_by_name['MediaAudio'] = _MEDIAAUDIO
DESCRIPTOR.message_types_by_name['MediaVideo'] = _MEDIAVIDEO
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

MediaFile = _reflection.GeneratedProtocolMessageType('MediaFile', (_message.Message,), dict(
  DESCRIPTOR = _MEDIAFILE,
  __module__ = 'google.ads.googleads_v2.proto.resources.media_file_pb2'
  ,
  __doc__ = """A media file.
  
  
  Attributes:
      resource_name:
          The resource name of the media file. Media file resource names
          have the form:
          ``customers/{customer_id}/mediaFiles/{media_file_id}``
      id:
          The ID of the media file.
      type:
          Type of the media file.
      mime_type:
          The mime type of the media file.
      source_url:
          The URL of where the original media file was downloaded from
          (or a file name). Only used for media of type AUDIO and IMAGE.
      name:
          The name of the media file. The name can be used by clients to
          help identify previously uploaded media.
      file_size:
          The size of the media file in bytes.
      mediatype:
          The specific type of the media file.
      image:
          Encapsulates an Image.
      media_bundle:
          A ZIP archive media the content of which contains HTML5
          assets.
      audio:
          Encapsulates an Audio.
      video:
          Encapsulates a Video.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.resources.MediaFile)
  ))
_sym_db.RegisterMessage(MediaFile)

MediaImage = _reflection.GeneratedProtocolMessageType('MediaImage', (_message.Message,), dict(
  DESCRIPTOR = _MEDIAIMAGE,
  __module__ = 'google.ads.googleads_v2.proto.resources.media_file_pb2'
  ,
  __doc__ = """Encapsulates an Image.
  
  
  Attributes:
      data:
          Raw image data.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.resources.MediaImage)
  ))
_sym_db.RegisterMessage(MediaImage)

MediaBundle = _reflection.GeneratedProtocolMessageType('MediaBundle', (_message.Message,), dict(
  DESCRIPTOR = _MEDIABUNDLE,
  __module__ = 'google.ads.googleads_v2.proto.resources.media_file_pb2'
  ,
  __doc__ = """Represents a ZIP archive media the content of which contains HTML5
  assets.
  
  
  Attributes:
      data:
          Raw zipped data.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.resources.MediaBundle)
  ))
_sym_db.RegisterMessage(MediaBundle)

MediaAudio = _reflection.GeneratedProtocolMessageType('MediaAudio', (_message.Message,), dict(
  DESCRIPTOR = _MEDIAAUDIO,
  __module__ = 'google.ads.googleads_v2.proto.resources.media_file_pb2'
  ,
  __doc__ = """Encapsulates an Audio.
  
  
  Attributes:
      ad_duration_millis:
          The duration of the Audio in milliseconds.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.resources.MediaAudio)
  ))
_sym_db.RegisterMessage(MediaAudio)

MediaVideo = _reflection.GeneratedProtocolMessageType('MediaVideo', (_message.Message,), dict(
  DESCRIPTOR = _MEDIAVIDEO,
  __module__ = 'google.ads.googleads_v2.proto.resources.media_file_pb2'
  ,
  __doc__ = """Encapsulates a Video.
  
  
  Attributes:
      ad_duration_millis:
          The duration of the Video in milliseconds.
      youtube_video_id:
          The YouTube video ID (as seen in YouTube URLs).
      advertising_id_code:
          The Advertising Digital Identification code for this video, as
          defined by the American Association of Advertising Agencies,
          used mainly for television commercials.
      isci_code:
          The Industry Standard Commercial Identifier code for this
          video, used mainly for television commercials.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.resources.MediaVideo)
  ))
_sym_db.RegisterMessage(MediaVideo)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v2/proto/resources/group_placement_view.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.ads.google_ads.v2.proto.enums import placement_type_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_placement__type__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v2/proto/resources/group_placement_view.proto',
  package='google.ads.googleads.v2.resources',
  syntax='proto3',
  serialized_options=_b('\n%com.google.ads.googleads.v2.resourcesB\027GroupPlacementViewProtoP\001ZJgoogle.golang.org/genproto/googleapis/ads/googleads/v2/resources;resources\242\002\003GAA\252\002!Google.Ads.GoogleAds.V2.Resources\312\002!Google\\Ads\\GoogleAds\\V2\\Resources\352\002%Google::Ads::GoogleAds::V2::Resources'),
  serialized_pb=_b('\nBgoogle/ads/googleads_v2/proto/resources/group_placement_view.proto\x12!google.ads.googleads.v2.resources\x1a\x38google/ads/googleads_v2/proto/enums/placement_type.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1cgoogle/api/annotations.proto\"\x9a\x02\n\x12GroupPlacementView\x12\x15\n\rresource_name\x18\x01 \x01(\t\x12/\n\tplacement\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x32\n\x0c\x64isplay_name\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x30\n\ntarget_url\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12V\n\x0eplacement_type\x18\x05 \x01(\x0e\x32>.google.ads.googleads.v2.enums.PlacementTypeEnum.PlacementTypeB\x84\x02\n%com.google.ads.googleads.v2.resourcesB\x17GroupPlacementViewProtoP\x01ZJgoogle.golang.org/genproto/googleapis/ads/googleads/v2/resources;resources\xa2\x02\x03GAA\xaa\x02!Google.Ads.GoogleAds.V2.Resources\xca\x02!Google\\Ads\\GoogleAds\\V2\\Resources\xea\x02%Google::Ads::GoogleAds::V2::Resourcesb\x06proto3')
  ,
  dependencies=[google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_placement__type__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,])




_GROUPPLACEMENTVIEW = _descriptor.Descriptor(
  name='GroupPlacementView',
  full_name='google.ads.googleads.v2.resources.GroupPlacementView',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_name', full_name='google.ads.googleads.v2.resources.GroupPlacementView.resource_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='placement', full_name='google.ads.googleads.v2.resources.GroupPlacementView.placement', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='display_name', full_name='google.ads.googleads.v2.resources.GroupPlacementView.display_name', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='target_url', full_name='google.ads.googleads.v2.resources.GroupPlacementView.target_url', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='placement_type', full_name='google.ads.googleads.v2.resources.GroupPlacementView.placement_type', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=226,
  serialized_end=508,
)

_GROUPPLACEMENTVIEW.fields_by_name['placement'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_GROUPPLACEMENTVIEW.fields_by_name['display_name'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_GROUPPLACEMENTVIEW.fields_by_name['target_url'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_GROUPPLACEMENTVIEW.fields_by_name['placement_type'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_placement__type__pb2._PLACEMENTTYPEENUM_PLACEMENTTYPE
DESCRIPTOR.message_types_by_name['GroupPlacementView'] = _GROUPPLACEMENTVIEW
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GroupPlacementView = _reflection.GeneratedProtocolMessageType('GroupPlacementView', (_message.Message,), dict(
  DESCRIPTOR = _GROUPPLACEMENTVIEW,
  __module__ = 'google.ads.googleads_v2.proto.resources.group_placement_view_pb2'
  ,
  __doc__ = """A group placement view.
  
  
  Attributes:
      resource_name:
          The resource name of the group placement view. Group placement
          view resource names have the form:  ``customers/{customer_id}/
          groupPlacementViews/{ad_group_id}~{base64_placement}``
      placement:
          The automatic placement string at group level, e. g. web
          domain, mobile app ID, or a YouTube channel ID.
      display_name:
          Domain name for websites and YouTube channel name for YouTube
          channels.
      target_url:
          URL of the group placement, e.g. domain, link to the mobile
          application in app store, or a YouTube channel URL.
      placement_type:
          Type of the placement, e.g. Website, YouTube Channel, Mobile
          Application.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.resources.GroupPlacementView)
  ))
_sym_db.RegisterMessage(GroupPlacementView)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v2/proto/services/shared_criterion_service.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.ads.google_ads.v2.proto.resources import shared_criterion_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_shared__criterion__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.rpc import status_pb2 as google_dot_rpc_dot_status__pb2
from google.api import client_pb2 as google_dot_api_dot_client__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v2/proto/services/shared_criterion_service.proto',
  package='google.ads.googleads.v2.services',
  syntax='proto3',
  serialized_options=_b('\n$com.google.ads.googleads.v2.servicesB\033SharedCriterionServiceProtoP\001ZHgoogle.golang.org/genproto/googleapis/ads/googleads/v2/services;services\242\002\003GAA\252\002 Google.Ads.GoogleAds.V2.Services\312\002 Google\\Ads\\GoogleAds\\V2\\Services\352\002$Google::Ads::GoogleAds::V2::Services'),
  serialized_pb=_b('\nEgoogle/ads/googleads_v2/proto/services/shared_criterion_service.proto\x12 google.ads.googleads.v2.services\x1a>google/ads/googleads_v2/proto/resources/shared_criterion.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x17google/rpc/status.proto\x1a\x17google/api/client.proto\"2\n\x19GetSharedCriterionRequest\x12\x15\n\rresource_name\x18\x01 \x01(\t\"\xb2\x01\n\x1bMutateSharedCriteriaRequest\x12\x13\n\x0b\x63ustomer_id\x18\x01 \x01(\t\x12N\n\noperations\x18\x02 \x03(\x0b\x32:.google.ads.googleads.v2.services.SharedCriterionOperation\x12\x17\n\x0fpartial_failure\x18\x03 \x01(\x08\x12\x15\n\rvalidate_only\x18\x04 \x01(\x08\"\x7f\n\x18SharedCriterionOperation\x12\x44\n\x06\x63reate\x18\x01 \x01(\x0b\x32\x32.google.ads.googleads.v2.resources.SharedCriterionH\x00\x12\x10\n\x06remove\x18\x03 \x01(\tH\x00\x42\x0b\n\toperation\"\xa1\x01\n\x1cMutateSharedCriteriaResponse\x12\x31\n\x15partial_failure_error\x18\x03 \x01(\x0b\x32\x12.google.rpc.Status\x12N\n\x07results\x18\x02 \x03(\x0b\x32=.google.ads.googleads.v2.services.MutateSharedCriterionResult\"4\n\x1bMutateSharedCriterionResult\x12\x15\n\rresource_name\x18\x01 \x01(\t2\xcf\x03\n\x16SharedCriterionService\x12\xbf\x01\n\x12GetSharedCriterion\x12;.google.ads.googleads.v2.services.GetSharedCriterionRequest\x1a\x32.google.ads.googleads.v2.resources.SharedCriterion\"8\x82\xd3\xe4\x93\x02\x32\x12\x30/v2/{resource_name=customers/*/sharedCriteria/*}\x12\xd5\x01\n\x14MutateSharedCriteria\x12=.google.ads.googleads.v2.services.MutateSharedCriteriaRequest\x1a>.google.ads.googleads.v2.services.MutateSharedCriteriaResponse\">\x82\xd3\xe4\x93\x02\x38\"3/v2/customers/{customer_id=*}/sharedCriteria:mutate:\x01*\x1a\x1b\xca\x41\x18googleads.googleapis.comB\x82\x02\n$com.google.ads.googleads.v2.servicesB\x1bSharedCriterionServiceProtoP\x01ZHgoogle.golang.org/genproto/googleapis/ads/googleads/v2/services;services\xa2\x02\x03GAA\xaa\x02 Google.Ads.GoogleAds.V2.Services\xca\x02 Google\\Ads\\GoogleAds\\V2\\Services\xea\x02$Google::Ads::GoogleAds::V2::Servicesb\x06proto3')
  ,
  dependencies=[google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_shared__criterion__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,google_dot_rpc_dot_status__pb2.DESCRIPTOR,google_dot_api_dot_client__pb2.DESCRIPTOR,])




_GETSHAREDCRITERIONREQUEST = _descriptor.Descriptor(
  name='GetSharedCriterionRequest',
  full_name='google.ads.googleads.v2.services.GetSharedCriterionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_name', full_name='google.ads.googleads.v2.services.GetSharedCriterionRequest.resource_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=251,
  serialized_end=301,
)


_MUTATESHAREDCRITERIAREQUEST = _descriptor.Descriptor(
  name='MutateSharedCriteriaRequest',
  full_name='google.ads.googleads.v2.services.MutateSharedCriteriaRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='customer_id', full_name='google.ads.googleads.v2.services.MutateSharedCriteriaRequest.customer_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='operations', full_name='google.ads.googleads.v2.services.MutateSharedCriteriaRequest.operations', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='partial_failure', full_name='google.ads.googleads.v2.services.MutateSharedCriteriaRequest.partial_failure', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='validate_only', full_name='google.ads.googleads.v2.services.MutateSharedCriteriaRequest.validate_only', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=304,
  serialized_end=482,
)


_SHAREDCRITERIONOPERATION = _descriptor.Descriptor(
  name='SharedCriterionOperation',
  full_name='google.ads.googleads.v2.services.SharedCriterionOperation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='create', full_name='google.ads.googleads.v2.services.SharedCriterionOperation.create', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='remove', full_name='google.ads.googleads.v2.services.SharedCriterionOperation.remove', index=1,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='operation', full_name='google.ads.googleads.v2.services.SharedCriterionOperation.operation',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=484,
  serialized_end=611,
)


_MUTATESHAREDCRITERIARESPONSE = _descriptor.Descriptor(
  name='MutateSharedCriteriaResponse',
  full_name='google.ads.googleads.v2.services.MutateSharedCriteriaResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='partial_failure_error', full_name='google.ads.googleads.v2.services.MutateSharedCriteriaResponse.partial_failure_error', index=0,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='results', full_name='google.ads.googleads.v2.services.MutateSharedCriteriaResponse.results', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=614,
  serialized_end=775,
)


_MUTATESHAREDCRITERIONRESULT = _descriptor.Descriptor(
  name='MutateSharedCriterionResult',
  full_name='google.ads.googleads.v2.services.MutateSharedCriterionResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_name', full_name='google.ads.googleads.v2.services.MutateSharedCriterionResult.resource_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=777,
  serialized_end=829,
)

_MUTATESHAREDCRITERIAREQUEST.fields_by_name['operations'].message_type = _SHAREDCRITERIONOPERATION
_SHAREDCRITERIONOPERATION.fields_by_name['create'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_shared__criterion__pb2._SHAREDCRITERION
_SHAREDCRITERIONOPERATION.oneofs_by_name['operation'].fields.append(
  _SHAREDCRITERIONOPERATION.fields_by_name['create'])
_SHAREDCRITERIONOPERATION.fields_by_name['create'].containing_oneof = _SHAREDCRITERIONOPERATION.oneofs_by_name['operation']
_SHAREDCRITERIONOPERATION.oneofs_by_name['operation'].fields.append(
  _SHAREDCRITERIONOPERATION.fields_by_name['remove'])
_SHAREDCRITERIONOPERATION.fields_by_name['remove'].containing_oneof = _SHAREDCRITERIONOPERATION.oneofs_by_name['operation']
_MUTATESHAREDCRITERIARESPONSE.fields_by_name['partial_failure_error'].message_type = google_dot_rpc_dot_status__pb2._STATUS
_MUTATESHAREDCRITERIARESPONSE.fields_by_name['results'].message_type = _MUTATESHAREDCRITERIONRESULT
DESCRIPTOR.message_types_by_name['GetSharedCriterionRequest'] = _GETSHAREDCRITERIONREQUEST
DESCRIPTOR.message_types_by_name['MutateSharedCriteriaRequest'] = _MUTATESHAREDCRITERIAREQUEST
DESCRIPTOR.message_types_by_name['SharedCriterionOperation'] = _SHAREDCRITERIONOPERATION
DESCRIPTOR.message_types_by_name['MutateSharedCriteriaResponse'] = _MUTATESHAREDCRITERIARESPONSE
DESCRIPTOR.message_types_by_name['MutateSharedCriterionResult'] = _MUTATESHAREDCRITERIONRESULT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetSharedCriterionRequest = _reflection.GeneratedProtocolMessageType('GetSharedCriterionRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETSHAREDCRITERIONREQUEST,
  __module__ = 'google.ads.googleads_v2.proto.services.shared_criterion_service_pb2'
  ,
  __doc__ = """Request message for
  [SharedCriterionService.GetSharedCriterion][google.ads.googleads.v2.services.SharedCriterionService.GetSharedCriterion].
  
  
  Attributes:
      resource_name:
          The resource name of the shared criterion to fetch.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.services.GetSharedCriterionRequest)
  ))
_sym_db.RegisterMessage(GetSharedCriterionRequest)

MutateSharedCriteriaRequest = _reflection.GeneratedProtocolMessageType('MutateSharedCriteriaRequest', (_message.Message,), dict(
  DESCRIPTOR = _MUTATESHAREDCRITERIAREQUEST,
  __module__ = 'google.ads.googleads_v2.proto.services.shared_criterion_service_pb2'
  ,
  __doc__ = """Request message for
  [SharedCriterionService.MutateSharedCriteria][google.ads.googleads.v2.services.SharedCriterionService.MutateSharedCriteria].
  
  
  Attributes:
      customer_id:
          The ID of the customer whose shared criteria are being
          modified.
      operations:
          The list of operations to perform on individual shared
          criteria.
      partial_failure:
          If true, successful operations will be carried out and invalid
          operations will return errors. If false, all operations will
          be carried out in one transaction if and only if they are all
          valid. Default is false.
      validate_only:
          If true, the request is validated but not executed. Only
          errors are returned, not results.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.services.MutateSharedCriteriaRequest)
  ))
_sym_db.RegisterMessage(MutateSharedCriteriaRequest)

SharedCriterionOperation = _reflection.GeneratedProtocolMessageType('SharedCriterionOperation', (_message.Message,), dict(
  DESCRIPTOR = _SHAREDCRITERIONOPERATION,
  __module__ = 'google.ads.googleads_v2.proto.services.shared_criterion_service_pb2'
  ,
  __doc__ = """A single operation (create, remove) on an shared criterion.
  
  
  Attributes:
      operation:
          The mutate operation.
      create:
          Create operation: No resource name is expected for the new
          shared criterion.
      remove:
          Remove operation: A resource name for the removed shared
          criterion is expected, in this format:  ``customers/{customer_
          id}/sharedCriteria/{shared_set_id}~{criterion_id}``
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.services.SharedCriterionOperation)
  ))
_sym_db.RegisterMessage(SharedCriterionOperation)

MutateSharedCriteriaResponse = _reflection.GeneratedProtocolMessageType('MutateSharedCriteriaResponse', (_message.Message,), dict(
  DESCRIPTOR = _MUTATESHAREDCRITERIARESPONSE,
  __module__ = 'google.ads.googleads_v2.proto.services.shared_criterion_service_pb2'
  ,
  __doc__ = """Response message for a shared criterion mutate.
  
  
  Attributes:
      partial_failure_error:
          Errors that pertain to operation failures in the partial
          failure mode. Returned only when partial\_failure = true and
          all errors occur inside the operations. If any errors occur
          outside the operations (e.g. auth errors), we return an RPC
          level error.
      results:
          All results for the mutate.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.services.MutateSharedCriteriaResponse)
  ))
_sym_db.RegisterMessage(MutateSharedCriteriaResponse)

MutateSharedCriterionResult = _reflection.GeneratedProtocolMessageType('MutateSharedCriterionResult', (_message.Message,), dict(
  DESCRIPTOR = _MUTATESHAREDCRITERIONRESULT,
  __module__ = 'google.ads.googleads_v2.proto.services.shared_criterion_service_pb2'
  ,
  __doc__ = """The result for the shared criterion mutate.
  
  
  Attributes:
      resource_name:
          Returned for successful operations.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.services.MutateSharedCriterionResult)
  ))
_sym_db.RegisterMessage(MutateSharedCriterionResult)


DESCRIPTOR._options = None

_SHAREDCRITERIONSERVICE = _descriptor.ServiceDescriptor(
  name='SharedCriterionService',
  full_name='google.ads.googleads.v2.services.SharedCriterionService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=_b('\312A\030googleads.googleapis.com'),
  serialized_start=832,
  serialized_end=1295,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetSharedCriterion',
    full_name='google.ads.googleads.v2.services.SharedCriterionService.GetSharedCriterion',
    index=0,
    containing_service=None,
    input_type=_GETSHAREDCRITERIONREQUEST,
    output_type=google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_shared__criterion__pb2._SHAREDCRITERION,
    serialized_options=_b('\202\323\344\223\0022\0220/v2/{resource_name=customers/*/sharedCriteria/*}'),
  ),
  _descriptor.MethodDescriptor(
    name='MutateSharedCriteria',
    full_name='google.ads.googleads.v2.services.SharedCriterionService.MutateSharedCriteria',
    index=1,
    containing_service=None,
    input_type=_MUTATESHAREDCRITERIAREQUEST,
    output_type=_MUTATESHAREDCRITERIARESPONSE,
    serialized_options=_b('\202\323\344\223\0028\"3/v2/customers/{customer_id=*}/sharedCriteria:mutate:\001*'),
  ),
])
_sym_db.RegisterServiceDescriptor(_SHAREDCRITERIONSERVICE)

DESCRIPTOR.services_by_name['SharedCriterionService'] = _SHAREDCRITERIONSERVICE

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v1/proto/resources/keyword_plan_keyword.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.ads.google_ads.v1.proto.enums import keyword_match_type_pb2 as google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_keyword__match__type__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v1/proto/resources/keyword_plan_keyword.proto',
  package='google.ads.googleads.v1.resources',
  syntax='proto3',
  serialized_options=_b('\n%com.google.ads.googleads.v1.resourcesB\027KeywordPlanKeywordProtoP\001ZJgoogle.golang.org/genproto/googleapis/ads/googleads/v1/resources;resources\242\002\003GAA\252\002!Google.Ads.GoogleAds.V1.Resources\312\002!Google\\Ads\\GoogleAds\\V1\\Resources\352\002%Google::Ads::GoogleAds::V1::Resources'),
  serialized_pb=_b('\nBgoogle/ads/googleads_v1/proto/resources/keyword_plan_keyword.proto\x12!google.ads.googleads.v1.resources\x1a<google/ads/googleads_v1/proto/enums/keyword_match_type.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1cgoogle/api/annotations.proto\"\xcc\x02\n\x12KeywordPlanKeyword\x12\x15\n\rresource_name\x18\x01 \x01(\t\x12;\n\x15keyword_plan_ad_group\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\'\n\x02id\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12*\n\x04text\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12X\n\nmatch_type\x18\x05 \x01(\x0e\x32\x44.google.ads.googleads.v1.enums.KeywordMatchTypeEnum.KeywordMatchType\x12\x33\n\x0e\x63pc_bid_micros\x18\x06 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x84\x02\n%com.google.ads.googleads.v1.resourcesB\x17KeywordPlanKeywordProtoP\x01ZJgoogle.golang.org/genproto/googleapis/ads/googleads/v1/resources;resources\xa2\x02\x03GAA\xaa\x02!Google.Ads.GoogleAds.V1.Resources\xca\x02!Google\\Ads\\GoogleAds\\V1\\Resources\xea\x02%Google::Ads::GoogleAds::V1::Resourcesb\x06proto3')
  ,
  dependencies=[google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_keyword__match__type__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,])




_KEYWORDPLANKEYWORD = _descriptor.Descriptor(
  name='KeywordPlanKeyword',
  full_name='google.ads.googleads.v1.resources.KeywordPlanKeyword',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_name', full_name='google.ads.googleads.v1.resources.KeywordPlanKeyword.resource_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='keyword_plan_ad_group', full_name='google.ads.googleads.v1.resources.KeywordPlanKeyword.keyword_plan_ad_group', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='id', full_name='google.ads.googleads.v1.resources.KeywordPlanKeyword.id', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='text', full_name='google.ads.googleads.v1.resources.KeywordPlanKeyword.text', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='match_type', full_name='google.ads.googleads.v1.resources.KeywordPlanKeyword.match_type', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cpc_bid_micros', full_name='google.ads.googleads.v1.resources.KeywordPlanKeyword.cpc_bid_micros', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=230,
  serialized_end=562,
)

_KEYWORDPLANKEYWORD.fields_by_name['keyword_plan_ad_group'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_KEYWORDPLANKEYWORD.fields_by_name['id'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_KEYWORDPLANKEYWORD.fields_by_name['text'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_KEYWORDPLANKEYWORD.fields_by_name['match_type'].enum_type = google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_keyword__match__type__pb2._KEYWORDMATCHTYPEENUM_KEYWORDMATCHTYPE
_KEYWORDPLANKEYWORD.fields_by_name['cpc_bid_micros'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
DESCRIPTOR.message_types_by_name['KeywordPlanKeyword'] = _KEYWORDPLANKEYWORD
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

KeywordPlanKeyword = _reflection.GeneratedProtocolMessageType('KeywordPlanKeyword', (_message.Message,), dict(
  DESCRIPTOR = _KEYWORDPLANKEYWORD,
  __module__ = 'google.ads.googleads_v1.proto.resources.keyword_plan_keyword_pb2'
  ,
  __doc__ = """A Keyword Plan ad group keyword. Max number of keyword plan keywords per
  plan: 2500.
  
  
  Attributes:
      resource_name:
          The resource name of the Keyword Plan ad group keyword.
          KeywordPlanKeyword resource names have the form:  ``customers/
          {customer_id}/keywordPlanKeywords/{kp_ad_group_keyword_id}``
      keyword_plan_ad_group:
          The Keyword Plan ad group to which this keyword belongs.
      id:
          The ID of the Keyword Plan keyword.
      text:
          The keyword text.
      match_type:
          The keyword match type.
      cpc_bid_micros:
          A keyword level max cpc bid in micros, in the account
          currency, that overrides the keyword plan ad group cpc bid.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.resources.KeywordPlanKeyword)
  ))
_sym_db.RegisterMessage(KeywordPlanKeyword)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from google.ads.google_ads.v2.proto.resources import campaign_feed_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_campaign__feed__pb2
from google.ads.google_ads.v2.proto.services import campaign_feed_service_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_campaign__feed__service__pb2


class CampaignFeedServiceStub(object):
  """Proto file describing the CampaignFeed service.

  Service to manage campaign feeds.
  """

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.GetCampaignFeed = channel.unary_unary(
        '/google.ads.googleads.v2.services.CampaignFeedService/GetCampaignFeed',
        request_serializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_campaign__feed__service__pb2.GetCampaignFeedRequest.SerializeToString,
        response_deserializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_campaign__feed__pb2.CampaignFeed.FromString,
        )
    self.MutateCampaignFeeds = channel.unary_unary(
        '/google.ads.googleads.v2.services.CampaignFeedService/MutateCampaignFeeds',
        request_serializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_campaign__feed__service__pb2.MutateCampaignFeedsRequest.SerializeToString,
        response_deserializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_campaign__feed__service__pb2.MutateCampaignFeedsResponse.FromString,
        )


class CampaignFeedServiceServicer(object):
  """Proto file describing the CampaignFeed service.

  Service to manage campaign feeds.
  """

  def GetCampaignFeed(self, request, context):
    """Returns the requested campaign feed in full detail.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def MutateCampaignFeeds(self, request, context):
    """Creates, updates, or removes campaign feeds. Operation statuses are
    returned.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_CampaignFeedServiceServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'GetCampaignFeed': grpc.unary_unary_rpc_method_handler(
          servicer.GetCampaignFeed,
          request_deserializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_campaign__feed__service__pb2.GetCampaignFeedRequest.FromString,
          response_serializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_campaign__feed__pb2.CampaignFeed.SerializeToString,
      ),
      'MutateCampaignFeeds': grpc.unary_unary_rpc_method_handler(
          servicer.MutateCampaignFeeds,
          request_deserializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_campaign__feed__service__pb2.MutateCampaignFeedsRequest.FromString,
          response_serializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_campaign__feed__service__pb2.MutateCampaignFeedsResponse.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'google.ads.googleads.v2.services.CampaignFeedService', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))



# -*- coding: utf-8 -*-
#
# Copyright 2019 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     https://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

import google.api_core.grpc_helpers
import google.api_core.operations_v1

from google.ads.google_ads.v1.proto.services import campaign_experiment_service_pb2_grpc


class CampaignExperimentServiceGrpcTransport(object):
    """gRPC transport class providing stubs for
    google.ads.googleads.v1.services CampaignExperimentService API.

    The transport provides access to the raw gRPC stubs,
    which can be used to take advantage of advanced
    features of gRPC.
    """
    # The scopes needed to make gRPC calls to all of the methods defined
    # in this service.
    _OAUTH_SCOPES = ()

    def __init__(self,
                 channel=None,
                 credentials=None,
                 address='googleads.googleapis.com:443'):
        """Instantiate the transport class.

        Args:
            channel (grpc.Channel): A ``Channel`` instance through
                which to make calls. This argument is mutually exclusive
                with ``credentials``; providing both will raise an exception.
            credentials (google.auth.credentials.Credentials): The
                authorization credentials to attach to requests. These
                credentials identify this application to the service. If none
                are specified, the client will attempt to ascertain the
                credentials from the environment.
            address (str): The address where the service is hosted.
        """
        # If both `channel` and `credentials` are specified, raise an
        # exception (channels come with credentials baked in already).
        if channel is not None and credentials is not None:
            raise ValueError(
                'The `channel` and `credentials` arguments are mutually '
                'exclusive.', )

        # Create the channel.
        if channel is None:
            channel = self.create_channel(
                address=address,
                credentials=credentials,
            )

        self._channel = channel

        # gRPC uses objects called "stubs" that are bound to the
        # channel and provide a basic method for each RPC.
        self._stubs = {
            'campaign_experiment_service_stub': campaign_experiment_service_pb2_grpc.CampaignExperimentServiceStub(channel),
        }

        # Because this API includes a method that returns a
        # long-running operation (proto: google.longrunning.Operation),
        # instantiate an LRO client.
        self._operations_client = google.api_core.operations_v1.OperationsClient(channel)

    @classmethod
    def create_channel(
                cls,
                address='googleads.googleapis.com:443',
                credentials=None,
                **kwargs):
        """Create and return a gRPC channel object.

        Args:
            address (str): The host for the channel to use.
            credentials (~.Credentials): The
                authorization credentials to attach to requests. These
                credentials identify this application to the service. If
                none are specified, the client will attempt to ascertain
                the credentials from the environment.
            kwargs (dict): Keyword arguments, which are passed to the
                channel creation.

        Returns:
            grpc.Channel: A gRPC channel object.
        """
        return google.api_core.grpc_helpers.create_channel(
            address,
            credentials=credentials,
            scopes=cls._OAUTH_SCOPES,
            **kwargs
        )

    @property
    def channel(self):
        """The gRPC channel used by the transport.

        Returns:
            grpc.Channel: A gRPC channel object.
        """
        return self._channel

    @property
    def get_campaign_experiment(self):
        """Return the gRPC stub for :meth:`CampaignExperimentServiceClient.get_campaign_experiment`.

        Returns the requested campaign experiment in full detail.

        Returns:
            Callable: A callable which accepts the appropriate
                deserialized request object and returns a
                deserialized response object.
        """
        return self._stubs[
            'campaign_experiment_service_stub'].GetCampaignExperiment

    @property
    def create_campaign_experiment(self):
        """Return the gRPC stub for :meth:`CampaignExperimentServiceClient.create_campaign_experiment`.

        Creates a campaign experiment based on a campaign draft. The draft campaign
        will be forked into a real campaign (called the experiment campaign) that
        will begin serving ads if successfully created.

        The campaign experiment is created immediately with status INITIALIZING.
        This method return a long running operation that tracks the forking of the
        draft campaign. If the forking fails, a list of errors can be retrieved
        using the ListCampaignExperimentAsyncErrors method. The operation's
        metadata will be a StringValue containing the resource name of the created
        campaign experiment.

        Returns:
            Callable: A callable which accepts the appropriate
                deserialized request object and returns a
                deserialized response object.
        """
        return self._stubs[
            'campaign_experiment_service_stub'].CreateCampaignExperiment

    @property
    def mutate_campaign_experiments(self):
        """Return the gRPC stub for :meth:`CampaignExperimentServiceClient.mutate_campaign_experiments`.

        Updates campaign experiments. Operation statuses are returned.

        Returns:
            Callable: A callable which accepts the appropriate
                deserialized request object and returns a
                deserialized response object.
        """
        return self._stubs[
            'campaign_experiment_service_stub'].MutateCampaignExperiments

    @property
    def graduate_campaign_experiment(self):
        """Return the gRPC stub for :meth:`CampaignExperimentServiceClient.graduate_campaign_experiment`.

        Graduates a campaign experiment to a full campaign. The base and experiment
        campaigns will start running independently with their own budgets.

        Returns:
            Callable: A callable which accepts the appropriate
                deserialized request object and returns a
                deserialized response object.
        """
        return self._stubs[
            'campaign_experiment_service_stub'].GraduateCampaignExperiment

    @property
    def promote_campaign_experiment(self):
        """Return the gRPC stub for :meth:`CampaignExperimentServiceClient.promote_campaign_experiment`.

        Promotes the changes in a experiment campaign back to the base campaign.

        The campaign experiment is updated immediately with status PROMOTING.
        This method return a long running operation that tracks the promoting of
        the experiment campaign. If the promoting fails, a list of errors can be
        retrieved using the ListCampaignExperimentAsyncErrors method.

        Returns:
            Callable: A callable which accepts the appropriate
                deserialized request object and returns a
                deserialized response object.
        """
        return self._stubs[
            'campaign_experiment_service_stub'].PromoteCampaignExperiment

    @property
    def end_campaign_experiment(self):
        """Return the gRPC stub for :meth:`CampaignExperimentServiceClient.end_campaign_experiment`.

        Immediately ends a campaign experiment, changing the experiment's scheduled
        end date and without waiting for end of day. End date is updated to be the
        time of the request.

        Returns:
            Callable: A callable which accepts the appropriate
                deserialized request object and returns a
                deserialized response object.
        """
        return self._stubs[
            'campaign_experiment_service_stub'].EndCampaignExperiment

    @property
    def list_campaign_experiment_async_errors(self):
        """Return the gRPC stub for :meth:`CampaignExperimentServiceClient.list_campaign_experiment_async_errors`.

        Returns all errors that occurred during CampaignExperiment create or
        promote (whichever occurred last).
        Supports standard list paging.

        Returns:
            Callable: A callable which accepts the appropriate
                deserialized request object and returns a
                deserialized response object.
        """
        return self._stubs[
            'campaign_experiment_service_stub'].ListCampaignExperimentAsyncErrors



config = {
  "interfaces": {
    "google.ads.googleads.v2.services.TopicConstantService": {
      "retry_codes": {
        "idempotent": [
          "DEADLINE_EXCEEDED",
          "UNAVAILABLE"
        ],
        "non_idempotent": []
      },
      "retry_params": {
        "default": {
          "initial_retry_delay_millis": 5000,
          "retry_delay_multiplier": 1.3,
          "max_retry_delay_millis": 60000,
          "initial_rpc_timeout_millis": 3600000,
          "rpc_timeout_multiplier": 1.0,
          "max_rpc_timeout_millis": 3600000,
          "total_timeout_millis": 3600000
        }
      },
      "methods": {
        "GetTopicConstant": {
          "timeout_millis": 60000,
          "retry_codes_name": "idempotent",
          "retry_params_name": "default"
        }
      }
    }
  }
}



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from google.ads.google_ads.v2.proto.resources import ad_group_ad_asset_view_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_ad__group__ad__asset__view__pb2
from google.ads.google_ads.v2.proto.services import ad_group_ad_asset_view_service_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_ad__group__ad__asset__view__service__pb2


class AdGroupAdAssetViewServiceStub(object):
  """Proto file describing the ad group ad asset view service.

  Service to fetch ad group ad asset views.
  """

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.GetAdGroupAdAssetView = channel.unary_unary(
        '/google.ads.googleads.v2.services.AdGroupAdAssetViewService/GetAdGroupAdAssetView',
        request_serializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_ad__group__ad__asset__view__service__pb2.GetAdGroupAdAssetViewRequest.SerializeToString,
        response_deserializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_ad__group__ad__asset__view__pb2.AdGroupAdAssetView.FromString,
        )


class AdGroupAdAssetViewServiceServicer(object):
  """Proto file describing the ad group ad asset view service.

  Service to fetch ad group ad asset views.
  """

  def GetAdGroupAdAssetView(self, request, context):
    """Returns the requested ad group ad asset view in full detail.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_AdGroupAdAssetViewServiceServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'GetAdGroupAdAssetView': grpc.unary_unary_rpc_method_handler(
          servicer.GetAdGroupAdAssetView,
          request_deserializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_ad__group__ad__asset__view__service__pb2.GetAdGroupAdAssetViewRequest.FromString,
          response_serializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_ad__group__ad__asset__view__pb2.AdGroupAdAssetView.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'google.ads.googleads.v2.services.AdGroupAdAssetViewService', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v1/proto/resources/billing_setup.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.ads.google_ads.v1.proto.enums import billing_setup_status_pb2 as google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_billing__setup__status__pb2
from google.ads.google_ads.v1.proto.enums import time_type_pb2 as google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_time__type__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v1/proto/resources/billing_setup.proto',
  package='google.ads.googleads.v1.resources',
  syntax='proto3',
  serialized_options=_b('\n%com.google.ads.googleads.v1.resourcesB\021BillingSetupProtoP\001ZJgoogle.golang.org/genproto/googleapis/ads/googleads/v1/resources;resources\242\002\003GAA\252\002!Google.Ads.GoogleAds.V1.Resources\312\002!Google\\Ads\\GoogleAds\\V1\\Resources\352\002%Google::Ads::GoogleAds::V1::Resources'),
  serialized_pb=_b('\n;google/ads/googleads_v1/proto/resources/billing_setup.proto\x12!google.ads.googleads.v1.resources\x1a>google/ads/googleads_v1/proto/enums/billing_setup_status.proto\x1a\x33google/ads/googleads_v1/proto/enums/time_type.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1cgoogle/api/annotations.proto\"\xbb\x07\n\x0c\x42illingSetup\x12\x15\n\rresource_name\x18\x01 \x01(\t\x12\'\n\x02id\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12X\n\x06status\x18\x03 \x01(\x0e\x32H.google.ads.googleads.v1.enums.BillingSetupStatusEnum.BillingSetupStatus\x12\x36\n\x10payments_account\x18\x0b \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x62\n\x15payments_account_info\x18\x0c \x01(\x0b\x32\x43.google.ads.googleads.v1.resources.BillingSetup.PaymentsAccountInfo\x12\x37\n\x0fstart_date_time\x18\t \x01(\x0b\x32\x1c.google.protobuf.StringValueH\x00\x12O\n\x0fstart_time_type\x18\n \x01(\x0e\x32\x34.google.ads.googleads.v1.enums.TimeTypeEnum.TimeTypeH\x00\x12\x35\n\rend_date_time\x18\r \x01(\x0b\x32\x1c.google.protobuf.StringValueH\x01\x12M\n\rend_time_type\x18\x0e \x01(\x0e\x32\x34.google.ads.googleads.v1.enums.TimeTypeEnum.TimeTypeH\x01\x1a\xca\x02\n\x13PaymentsAccountInfo\x12\x39\n\x13payments_account_id\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12;\n\x15payments_account_name\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x39\n\x13payments_profile_id\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12;\n\x15payments_profile_name\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x43\n\x1dsecondary_payments_profile_id\x18\x05 \x01(\x0b\x32\x1c.google.protobuf.StringValueB\x0c\n\nstart_timeB\n\n\x08\x65nd_timeB\xfe\x01\n%com.google.ads.googleads.v1.resourcesB\x11\x42illingSetupProtoP\x01ZJgoogle.golang.org/genproto/googleapis/ads/googleads/v1/resources;resources\xa2\x02\x03GAA\xaa\x02!Google.Ads.GoogleAds.V1.Resources\xca\x02!Google\\Ads\\GoogleAds\\V1\\Resources\xea\x02%Google::Ads::GoogleAds::V1::Resourcesb\x06proto3')
  ,
  dependencies=[google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_billing__setup__status__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_time__type__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,])




_BILLINGSETUP_PAYMENTSACCOUNTINFO = _descriptor.Descriptor(
  name='PaymentsAccountInfo',
  full_name='google.ads.googleads.v1.resources.BillingSetup.PaymentsAccountInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='payments_account_id', full_name='google.ads.googleads.v1.resources.BillingSetup.PaymentsAccountInfo.payments_account_id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='payments_account_name', full_name='google.ads.googleads.v1.resources.BillingSetup.PaymentsAccountInfo.payments_account_name', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='payments_profile_id', full_name='google.ads.googleads.v1.resources.BillingSetup.PaymentsAccountInfo.payments_profile_id', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='payments_profile_name', full_name='google.ads.googleads.v1.resources.BillingSetup.PaymentsAccountInfo.payments_profile_name', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='secondary_payments_profile_id', full_name='google.ads.googleads.v1.resources.BillingSetup.PaymentsAccountInfo.secondary_payments_profile_id', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=877,
  serialized_end=1207,
)

_BILLINGSETUP = _descriptor.Descriptor(
  name='BillingSetup',
  full_name='google.ads.googleads.v1.resources.BillingSetup',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_name', full_name='google.ads.googleads.v1.resources.BillingSetup.resource_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='id', full_name='google.ads.googleads.v1.resources.BillingSetup.id', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='status', full_name='google.ads.googleads.v1.resources.BillingSetup.status', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='payments_account', full_name='google.ads.googleads.v1.resources.BillingSetup.payments_account', index=3,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='payments_account_info', full_name='google.ads.googleads.v1.resources.BillingSetup.payments_account_info', index=4,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='start_date_time', full_name='google.ads.googleads.v1.resources.BillingSetup.start_date_time', index=5,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='start_time_type', full_name='google.ads.googleads.v1.resources.BillingSetup.start_time_type', index=6,
      number=10, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='end_date_time', full_name='google.ads.googleads.v1.resources.BillingSetup.end_date_time', index=7,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='end_time_type', full_name='google.ads.googleads.v1.resources.BillingSetup.end_time_type', index=8,
      number=14, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_BILLINGSETUP_PAYMENTSACCOUNTINFO, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='start_time', full_name='google.ads.googleads.v1.resources.BillingSetup.start_time',
      index=0, containing_type=None, fields=[]),
    _descriptor.OneofDescriptor(
      name='end_time', full_name='google.ads.googleads.v1.resources.BillingSetup.end_time',
      index=1, containing_type=None, fields=[]),
  ],
  serialized_start=278,
  serialized_end=1233,
)

_BILLINGSETUP_PAYMENTSACCOUNTINFO.fields_by_name['payments_account_id'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_BILLINGSETUP_PAYMENTSACCOUNTINFO.fields_by_name['payments_account_name'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_BILLINGSETUP_PAYMENTSACCOUNTINFO.fields_by_name['payments_profile_id'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_BILLINGSETUP_PAYMENTSACCOUNTINFO.fields_by_name['payments_profile_name'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_BILLINGSETUP_PAYMENTSACCOUNTINFO.fields_by_name['secondary_payments_profile_id'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_BILLINGSETUP_PAYMENTSACCOUNTINFO.containing_type = _BILLINGSETUP
_BILLINGSETUP.fields_by_name['id'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_BILLINGSETUP.fields_by_name['status'].enum_type = google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_billing__setup__status__pb2._BILLINGSETUPSTATUSENUM_BILLINGSETUPSTATUS
_BILLINGSETUP.fields_by_name['payments_account'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_BILLINGSETUP.fields_by_name['payments_account_info'].message_type = _BILLINGSETUP_PAYMENTSACCOUNTINFO
_BILLINGSETUP.fields_by_name['start_date_time'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_BILLINGSETUP.fields_by_name['start_time_type'].enum_type = google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_time__type__pb2._TIMETYPEENUM_TIMETYPE
_BILLINGSETUP.fields_by_name['end_date_time'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_BILLINGSETUP.fields_by_name['end_time_type'].enum_type = google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_time__type__pb2._TIMETYPEENUM_TIMETYPE
_BILLINGSETUP.oneofs_by_name['start_time'].fields.append(
  _BILLINGSETUP.fields_by_name['start_date_time'])
_BILLINGSETUP.fields_by_name['start_date_time'].containing_oneof = _BILLINGSETUP.oneofs_by_name['start_time']
_BILLINGSETUP.oneofs_by_name['start_time'].fields.append(
  _BILLINGSETUP.fields_by_name['start_time_type'])
_BILLINGSETUP.fields_by_name['start_time_type'].containing_oneof = _BILLINGSETUP.oneofs_by_name['start_time']
_BILLINGSETUP.oneofs_by_name['end_time'].fields.append(
  _BILLINGSETUP.fields_by_name['end_date_time'])
_BILLINGSETUP.fields_by_name['end_date_time'].containing_oneof = _BILLINGSETUP.oneofs_by_name['end_time']
_BILLINGSETUP.oneofs_by_name['end_time'].fields.append(
  _BILLINGSETUP.fields_by_name['end_time_type'])
_BILLINGSETUP.fields_by_name['end_time_type'].containing_oneof = _BILLINGSETUP.oneofs_by_name['end_time']
DESCRIPTOR.message_types_by_name['BillingSetup'] = _BILLINGSETUP
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

BillingSetup = _reflection.GeneratedProtocolMessageType('BillingSetup', (_message.Message,), dict(

  PaymentsAccountInfo = _reflection.GeneratedProtocolMessageType('PaymentsAccountInfo', (_message.Message,), dict(
    DESCRIPTOR = _BILLINGSETUP_PAYMENTSACCOUNTINFO,
    __module__ = 'google.ads.googleads_v1.proto.resources.billing_setup_pb2'
    ,
    __doc__ = """Container of Payments account information for this billing.
    
    
    Attributes:
        payments_account_id:
            A 16 digit id used to identify the Payments account associated
            with the billing setup.  This must be passed as a string with
            dashes, e.g. "1234-5678-9012-3456".
        payments_account_name:
            The name of the Payments account associated with the billing
            setup.  This enables the user to specify a meaningful name for
            a Payments account to aid in reconciling monthly invoices.
            This name will be printed in the monthly invoices.
        payments_profile_id:
            A 12 digit id used to identify the Payments profile associated
            with the billing setup.  This must be passed in as a string
            with dashes, e.g. "1234-5678-9012".
        payments_profile_name:
            The name of the Payments profile associated with the billing
            setup.
        secondary_payments_profile_id:
            A secondary payments profile id present in uncommon
            situations, e.g. when a sequential liability agreement has
            been arranged.
    """,
    # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.resources.BillingSetup.PaymentsAccountInfo)
    ))
  ,
  DESCRIPTOR = _BILLINGSETUP,
  __module__ = 'google.ads.googleads_v1.proto.resources.billing_setup_pb2'
  ,
  __doc__ = """A billing setup across Ads and Payments systems; an association between
  a Payments account and an advertiser. A billing setup is specific to one
  advertiser.
  
  
  Attributes:
      resource_name:
          The resource name of the billing setup. BillingSetup resource
          names have the form:
          ``customers/{customer_id}/billingSetups/{billing_setup_id}``
      id:
          The ID of the billing setup.
      status:
          The status of the billing setup.
      payments_account:
          The resource name of the Payments account associated with this
          billing setup. Payments resource names have the form:  ``custo
          mers/{customer_id}/paymentsAccounts/{payments_account_id}``
          When setting up billing, this is used to signup with an
          existing Payments account (and then payments\_account\_info
          should not be set). When getting a billing setup, this and
          payments\_account\_info will be populated.
      payments_account_info:
          The Payments account information associated with this billing
          setup. When setting up billing, this is used to signup with a
          new Payments account (and then payments\_account should not be
          set). When getting a billing setup, this and payments\_account
          will be populated.
      start_time:
          When creating a new billing setup, this is when the setup
          should take effect. NOW is the only acceptable start time if
          the customer doesn't have any approved setups.  When fetching
          an existing billing setup, this is the requested start time.
          However, if the setup was approved (see status) after the
          requested start time, then this is the approval time.
      start_date_time:
          The start date time in yyyy-MM-dd or yyyy-MM-dd HH:mm:ss
          format. Only a future time is allowed.
      start_time_type:
          The start time as a type. Only NOW is allowed.
      end_time:
          When the billing setup ends / ended. This is either FOREVER or
          the start time of the next scheduled billing setup.
      end_date_time:
          The end date time in yyyy-MM-dd or yyyy-MM-dd HH:mm:ss format.
      end_time_type:
          The end time as a type. The only possible value is FOREVER.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.resources.BillingSetup)
  ))
_sym_db.RegisterMessage(BillingSetup)
_sym_db.RegisterMessage(BillingSetup.PaymentsAccountInfo)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v2/proto/services/ad_group_criterion_service.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.ads.google_ads.v2.proto.common import policy_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_policy__pb2
from google.ads.google_ads.v2.proto.resources import ad_group_criterion_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_ad__group__criterion__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.rpc import status_pb2 as google_dot_rpc_dot_status__pb2
from google.api import client_pb2 as google_dot_api_dot_client__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v2/proto/services/ad_group_criterion_service.proto',
  package='google.ads.googleads.v2.services',
  syntax='proto3',
  serialized_options=_b('\n$com.google.ads.googleads.v2.servicesB\034AdGroupCriterionServiceProtoP\001ZHgoogle.golang.org/genproto/googleapis/ads/googleads/v2/services;services\242\002\003GAA\252\002 Google.Ads.GoogleAds.V2.Services\312\002 Google\\Ads\\GoogleAds\\V2\\Services\352\002$Google::Ads::GoogleAds::V2::Services'),
  serialized_pb=_b('\nGgoogle/ads/googleads_v2/proto/services/ad_group_criterion_service.proto\x12 google.ads.googleads.v2.services\x1a\x31google/ads/googleads_v2/proto/common/policy.proto\x1a@google/ads/googleads_v2/proto/resources/ad_group_criterion.proto\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\x1a\x17google/rpc/status.proto\x1a\x17google/api/client.proto\"3\n\x1aGetAdGroupCriterionRequest\x12\x15\n\rresource_name\x18\x01 \x01(\t\"\xb4\x01\n\x1cMutateAdGroupCriteriaRequest\x12\x13\n\x0b\x63ustomer_id\x18\x01 \x01(\t\x12O\n\noperations\x18\x02 \x03(\x0b\x32;.google.ads.googleads.v2.services.AdGroupCriterionOperation\x12\x17\n\x0fpartial_failure\x18\x03 \x01(\x08\x12\x15\n\rvalidate_only\x18\x04 \x01(\x08\"\xd3\x02\n\x19\x41\x64GroupCriterionOperation\x12/\n\x0bupdate_mask\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12X\n\x1c\x65xempt_policy_violation_keys\x18\x05 \x03(\x0b\x32\x32.google.ads.googleads.v2.common.PolicyViolationKey\x12\x45\n\x06\x63reate\x18\x01 \x01(\x0b\x32\x33.google.ads.googleads.v2.resources.AdGroupCriterionH\x00\x12\x45\n\x06update\x18\x02 \x01(\x0b\x32\x33.google.ads.googleads.v2.resources.AdGroupCriterionH\x00\x12\x10\n\x06remove\x18\x03 \x01(\tH\x00\x42\x0b\n\toperation\"\xa3\x01\n\x1dMutateAdGroupCriteriaResponse\x12\x31\n\x15partial_failure_error\x18\x03 \x01(\x0b\x32\x12.google.rpc.Status\x12O\n\x07results\x18\x02 \x03(\x0b\x32>.google.ads.googleads.v2.services.MutateAdGroupCriterionResult\"5\n\x1cMutateAdGroupCriterionResult\x12\x15\n\rresource_name\x18\x01 \x01(\t2\xd8\x03\n\x17\x41\x64GroupCriterionService\x12\xc3\x01\n\x13GetAdGroupCriterion\x12<.google.ads.googleads.v2.services.GetAdGroupCriterionRequest\x1a\x33.google.ads.googleads.v2.resources.AdGroupCriterion\"9\x82\xd3\xe4\x93\x02\x33\x12\x31/v2/{resource_name=customers/*/adGroupCriteria/*}\x12\xd9\x01\n\x15MutateAdGroupCriteria\x12>.google.ads.googleads.v2.services.MutateAdGroupCriteriaRequest\x1a?.google.ads.googleads.v2.services.MutateAdGroupCriteriaResponse\"?\x82\xd3\xe4\x93\x02\x39\"4/v2/customers/{customer_id=*}/adGroupCriteria:mutate:\x01*\x1a\x1b\xca\x41\x18googleads.googleapis.comB\x83\x02\n$com.google.ads.googleads.v2.servicesB\x1c\x41\x64GroupCriterionServiceProtoP\x01ZHgoogle.golang.org/genproto/googleapis/ads/googleads/v2/services;services\xa2\x02\x03GAA\xaa\x02 Google.Ads.GoogleAds.V2.Services\xca\x02 Google\\Ads\\GoogleAds\\V2\\Services\xea\x02$Google::Ads::GoogleAds::V2::Servicesb\x06proto3')
  ,
  dependencies=[google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_policy__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_ad__group__criterion__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,google_dot_protobuf_dot_field__mask__pb2.DESCRIPTOR,google_dot_rpc_dot_status__pb2.DESCRIPTOR,google_dot_api_dot_client__pb2.DESCRIPTOR,])




_GETADGROUPCRITERIONREQUEST = _descriptor.Descriptor(
  name='GetAdGroupCriterionRequest',
  full_name='google.ads.googleads.v2.services.GetAdGroupCriterionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_name', full_name='google.ads.googleads.v2.services.GetAdGroupCriterionRequest.resource_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=340,
  serialized_end=391,
)


_MUTATEADGROUPCRITERIAREQUEST = _descriptor.Descriptor(
  name='MutateAdGroupCriteriaRequest',
  full_name='google.ads.googleads.v2.services.MutateAdGroupCriteriaRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='customer_id', full_name='google.ads.googleads.v2.services.MutateAdGroupCriteriaRequest.customer_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='operations', full_name='google.ads.googleads.v2.services.MutateAdGroupCriteriaRequest.operations', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='partial_failure', full_name='google.ads.googleads.v2.services.MutateAdGroupCriteriaRequest.partial_failure', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='validate_only', full_name='google.ads.googleads.v2.services.MutateAdGroupCriteriaRequest.validate_only', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=394,
  serialized_end=574,
)


_ADGROUPCRITERIONOPERATION = _descriptor.Descriptor(
  name='AdGroupCriterionOperation',
  full_name='google.ads.googleads.v2.services.AdGroupCriterionOperation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='update_mask', full_name='google.ads.googleads.v2.services.AdGroupCriterionOperation.update_mask', index=0,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='exempt_policy_violation_keys', full_name='google.ads.googleads.v2.services.AdGroupCriterionOperation.exempt_policy_violation_keys', index=1,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='create', full_name='google.ads.googleads.v2.services.AdGroupCriterionOperation.create', index=2,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='update', full_name='google.ads.googleads.v2.services.AdGroupCriterionOperation.update', index=3,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='remove', full_name='google.ads.googleads.v2.services.AdGroupCriterionOperation.remove', index=4,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='operation', full_name='google.ads.googleads.v2.services.AdGroupCriterionOperation.operation',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=577,
  serialized_end=916,
)


_MUTATEADGROUPCRITERIARESPONSE = _descriptor.Descriptor(
  name='MutateAdGroupCriteriaResponse',
  full_name='google.ads.googleads.v2.services.MutateAdGroupCriteriaResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='partial_failure_error', full_name='google.ads.googleads.v2.services.MutateAdGroupCriteriaResponse.partial_failure_error', index=0,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='results', full_name='google.ads.googleads.v2.services.MutateAdGroupCriteriaResponse.results', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=919,
  serialized_end=1082,
)


_MUTATEADGROUPCRITERIONRESULT = _descriptor.Descriptor(
  name='MutateAdGroupCriterionResult',
  full_name='google.ads.googleads.v2.services.MutateAdGroupCriterionResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_name', full_name='google.ads.googleads.v2.services.MutateAdGroupCriterionResult.resource_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1084,
  serialized_end=1137,
)

_MUTATEADGROUPCRITERIAREQUEST.fields_by_name['operations'].message_type = _ADGROUPCRITERIONOPERATION
_ADGROUPCRITERIONOPERATION.fields_by_name['update_mask'].message_type = google_dot_protobuf_dot_field__mask__pb2._FIELDMASK
_ADGROUPCRITERIONOPERATION.fields_by_name['exempt_policy_violation_keys'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_policy__pb2._POLICYVIOLATIONKEY
_ADGROUPCRITERIONOPERATION.fields_by_name['create'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_ad__group__criterion__pb2._ADGROUPCRITERION
_ADGROUPCRITERIONOPERATION.fields_by_name['update'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_ad__group__criterion__pb2._ADGROUPCRITERION
_ADGROUPCRITERIONOPERATION.oneofs_by_name['operation'].fields.append(
  _ADGROUPCRITERIONOPERATION.fields_by_name['create'])
_ADGROUPCRITERIONOPERATION.fields_by_name['create'].containing_oneof = _ADGROUPCRITERIONOPERATION.oneofs_by_name['operation']
_ADGROUPCRITERIONOPERATION.oneofs_by_name['operation'].fields.append(
  _ADGROUPCRITERIONOPERATION.fields_by_name['update'])
_ADGROUPCRITERIONOPERATION.fields_by_name['update'].containing_oneof = _ADGROUPCRITERIONOPERATION.oneofs_by_name['operation']
_ADGROUPCRITERIONOPERATION.oneofs_by_name['operation'].fields.append(
  _ADGROUPCRITERIONOPERATION.fields_by_name['remove'])
_ADGROUPCRITERIONOPERATION.fields_by_name['remove'].containing_oneof = _ADGROUPCRITERIONOPERATION.oneofs_by_name['operation']
_MUTATEADGROUPCRITERIARESPONSE.fields_by_name['partial_failure_error'].message_type = google_dot_rpc_dot_status__pb2._STATUS
_MUTATEADGROUPCRITERIARESPONSE.fields_by_name['results'].message_type = _MUTATEADGROUPCRITERIONRESULT
DESCRIPTOR.message_types_by_name['GetAdGroupCriterionRequest'] = _GETADGROUPCRITERIONREQUEST
DESCRIPTOR.message_types_by_name['MutateAdGroupCriteriaRequest'] = _MUTATEADGROUPCRITERIAREQUEST
DESCRIPTOR.message_types_by_name['AdGroupCriterionOperation'] = _ADGROUPCRITERIONOPERATION
DESCRIPTOR.message_types_by_name['MutateAdGroupCriteriaResponse'] = _MUTATEADGROUPCRITERIARESPONSE
DESCRIPTOR.message_types_by_name['MutateAdGroupCriterionResult'] = _MUTATEADGROUPCRITERIONRESULT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetAdGroupCriterionRequest = _reflection.GeneratedProtocolMessageType('GetAdGroupCriterionRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETADGROUPCRITERIONREQUEST,
  __module__ = 'google.ads.googleads_v2.proto.services.ad_group_criterion_service_pb2'
  ,
  __doc__ = """Request message for
  [AdGroupCriterionService.GetAdGroupCriterion][google.ads.googleads.v2.services.AdGroupCriterionService.GetAdGroupCriterion].
  
  
  Attributes:
      resource_name:
          The resource name of the criterion to fetch.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.services.GetAdGroupCriterionRequest)
  ))
_sym_db.RegisterMessage(GetAdGroupCriterionRequest)

MutateAdGroupCriteriaRequest = _reflection.GeneratedProtocolMessageType('MutateAdGroupCriteriaRequest', (_message.Message,), dict(
  DESCRIPTOR = _MUTATEADGROUPCRITERIAREQUEST,
  __module__ = 'google.ads.googleads_v2.proto.services.ad_group_criterion_service_pb2'
  ,
  __doc__ = """Request message for
  [AdGroupCriterionService.MutateAdGroupCriteria][google.ads.googleads.v2.services.AdGroupCriterionService.MutateAdGroupCriteria].
  
  
  Attributes:
      customer_id:
          ID of the customer whose criteria are being modified.
      operations:
          The list of operations to perform on individual criteria.
      partial_failure:
          If true, successful operations will be carried out and invalid
          operations will return errors. If false, all operations will
          be carried out in one transaction if and only if they are all
          valid. Default is false.
      validate_only:
          If true, the request is validated but not executed. Only
          errors are returned, not results.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.services.MutateAdGroupCriteriaRequest)
  ))
_sym_db.RegisterMessage(MutateAdGroupCriteriaRequest)

AdGroupCriterionOperation = _reflection.GeneratedProtocolMessageType('AdGroupCriterionOperation', (_message.Message,), dict(
  DESCRIPTOR = _ADGROUPCRITERIONOPERATION,
  __module__ = 'google.ads.googleads_v2.proto.services.ad_group_criterion_service_pb2'
  ,
  __doc__ = """A single operation (create, remove, update) on an ad group criterion.
  
  
  Attributes:
      update_mask:
          FieldMask that determines which resource fields are modified
          in an update.
      exempt_policy_violation_keys:
          The list of policy violation keys that should not cause a
          PolicyViolationError to be reported. Not all policy violations
          are exemptable, please refer to the is\_exemptible field in
          the returned PolicyViolationError.  Resources violating these
          polices will be saved, but will not be eligible to serve. They
          may begin serving at a later time due to a change in policies,
          re-review of the resource, or a change in advertiser
          certificates.
      operation:
          The mutate operation.
      create:
          Create operation: No resource name is expected for the new
          criterion.
      update:
          Update operation: The criterion is expected to have a valid
          resource name.
      remove:
          Remove operation: A resource name for the removed criterion is
          expected, in this format:  ``customers/{customer_id}/adGroupCr
          iteria/{ad_group_id}~{criterion_id}``
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.services.AdGroupCriterionOperation)
  ))
_sym_db.RegisterMessage(AdGroupCriterionOperation)

MutateAdGroupCriteriaResponse = _reflection.GeneratedProtocolMessageType('MutateAdGroupCriteriaResponse', (_message.Message,), dict(
  DESCRIPTOR = _MUTATEADGROUPCRITERIARESPONSE,
  __module__ = 'google.ads.googleads_v2.proto.services.ad_group_criterion_service_pb2'
  ,
  __doc__ = """Response message for an ad group criterion mutate.
  
  
  Attributes:
      partial_failure_error:
          Errors that pertain to operation failures in the partial
          failure mode. Returned only when partial\_failure = true and
          all errors occur inside the operations. If any errors occur
          outside the operations (e.g. auth errors), we return an RPC
          level error.
      results:
          All results for the mutate.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.services.MutateAdGroupCriteriaResponse)
  ))
_sym_db.RegisterMessage(MutateAdGroupCriteriaResponse)

MutateAdGroupCriterionResult = _reflection.GeneratedProtocolMessageType('MutateAdGroupCriterionResult', (_message.Message,), dict(
  DESCRIPTOR = _MUTATEADGROUPCRITERIONRESULT,
  __module__ = 'google.ads.googleads_v2.proto.services.ad_group_criterion_service_pb2'
  ,
  __doc__ = """The result for the criterion mutate.
  
  
  Attributes:
      resource_name:
          Returned for successful operations.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.services.MutateAdGroupCriterionResult)
  ))
_sym_db.RegisterMessage(MutateAdGroupCriterionResult)


DESCRIPTOR._options = None

_ADGROUPCRITERIONSERVICE = _descriptor.ServiceDescriptor(
  name='AdGroupCriterionService',
  full_name='google.ads.googleads.v2.services.AdGroupCriterionService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=_b('\312A\030googleads.googleapis.com'),
  serialized_start=1140,
  serialized_end=1612,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetAdGroupCriterion',
    full_name='google.ads.googleads.v2.services.AdGroupCriterionService.GetAdGroupCriterion',
    index=0,
    containing_service=None,
    input_type=_GETADGROUPCRITERIONREQUEST,
    output_type=google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_ad__group__criterion__pb2._ADGROUPCRITERION,
    serialized_options=_b('\202\323\344\223\0023\0221/v2/{resource_name=customers/*/adGroupCriteria/*}'),
  ),
  _descriptor.MethodDescriptor(
    name='MutateAdGroupCriteria',
    full_name='google.ads.googleads.v2.services.AdGroupCriterionService.MutateAdGroupCriteria',
    index=1,
    containing_service=None,
    input_type=_MUTATEADGROUPCRITERIAREQUEST,
    output_type=_MUTATEADGROUPCRITERIARESPONSE,
    serialized_options=_b('\202\323\344\223\0029\"4/v2/customers/{customer_id=*}/adGroupCriteria:mutate:\001*'),
  ),
])
_sym_db.RegisterServiceDescriptor(_ADGROUPCRITERIONSERVICE)

DESCRIPTOR.services_by_name['AdGroupCriterionService'] = _ADGROUPCRITERIONSERVICE

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v2/proto/errors/campaign_budget_error.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v2/proto/errors/campaign_budget_error.proto',
  package='google.ads.googleads.v2.errors',
  syntax='proto3',
  serialized_options=_b('\n\"com.google.ads.googleads.v2.errorsB\030CampaignBudgetErrorProtoP\001ZDgoogle.golang.org/genproto/googleapis/ads/googleads/v2/errors;errors\242\002\003GAA\252\002\036Google.Ads.GoogleAds.V2.Errors\312\002\036Google\\Ads\\GoogleAds\\V2\\Errors\352\002\"Google::Ads::GoogleAds::V2::Errors'),
  serialized_pb=_b('\n@google/ads/googleads_v2/proto/errors/campaign_budget_error.proto\x12\x1egoogle.ads.googleads.v2.errors\x1a\x1cgoogle/api/annotations.proto\"\xe0\x05\n\x17\x43\x61mpaignBudgetErrorEnum\"\xc4\x05\n\x13\x43\x61mpaignBudgetError\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x0b\n\x07UNKNOWN\x10\x01\x12$\n CAMPAIGN_BUDGET_CANNOT_BE_SHARED\x10\x11\x12\x1b\n\x17\x43\x41MPAIGN_BUDGET_REMOVED\x10\x02\x12\x1a\n\x16\x43\x41MPAIGN_BUDGET_IN_USE\x10\x03\x12(\n$CAMPAIGN_BUDGET_PERIOD_NOT_AVAILABLE\x10\x04\x12<\n8CANNOT_MODIFY_FIELD_OF_IMPLICITLY_SHARED_CAMPAIGN_BUDGET\x10\x06\x12\x36\n2CANNOT_UPDATE_CAMPAIGN_BUDGET_TO_IMPLICITLY_SHARED\x10\x07\x12\x43\n?CANNOT_UPDATE_CAMPAIGN_BUDGET_TO_EXPLICITLY_SHARED_WITHOUT_NAME\x10\x08\x12\x36\n2CANNOT_UPDATE_CAMPAIGN_BUDGET_TO_EXPLICITLY_SHARED\x10\t\x12H\nDCANNOT_USE_IMPLICITLY_SHARED_CAMPAIGN_BUDGET_WITH_MULTIPLE_CAMPAIGNS\x10\n\x12\x12\n\x0e\x44UPLICATE_NAME\x10\x0b\x12\"\n\x1eMONEY_AMOUNT_IN_WRONG_CURRENCY\x10\x0c\x12/\n+MONEY_AMOUNT_LESS_THAN_CURRENCY_MINIMUM_CPC\x10\r\x12\x1a\n\x16MONEY_AMOUNT_TOO_LARGE\x10\x0e\x12\x19\n\x15NEGATIVE_MONEY_AMOUNT\x10\x0f\x12)\n%NON_MULTIPLE_OF_MINIMUM_CURRENCY_UNIT\x10\x10\x42\xf3\x01\n\"com.google.ads.googleads.v2.errorsB\x18\x43\x61mpaignBudgetErrorProtoP\x01ZDgoogle.golang.org/genproto/googleapis/ads/googleads/v2/errors;errors\xa2\x02\x03GAA\xaa\x02\x1eGoogle.Ads.GoogleAds.V2.Errors\xca\x02\x1eGoogle\\Ads\\GoogleAds\\V2\\Errors\xea\x02\"Google::Ads::GoogleAds::V2::Errorsb\x06proto3')
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,])



_CAMPAIGNBUDGETERRORENUM_CAMPAIGNBUDGETERROR = _descriptor.EnumDescriptor(
  name='CampaignBudgetError',
  full_name='google.ads.googleads.v2.errors.CampaignBudgetErrorEnum.CampaignBudgetError',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CAMPAIGN_BUDGET_CANNOT_BE_SHARED', index=2, number=17,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CAMPAIGN_BUDGET_REMOVED', index=3, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CAMPAIGN_BUDGET_IN_USE', index=4, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CAMPAIGN_BUDGET_PERIOD_NOT_AVAILABLE', index=5, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CANNOT_MODIFY_FIELD_OF_IMPLICITLY_SHARED_CAMPAIGN_BUDGET', index=6, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CANNOT_UPDATE_CAMPAIGN_BUDGET_TO_IMPLICITLY_SHARED', index=7, number=7,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CANNOT_UPDATE_CAMPAIGN_BUDGET_TO_EXPLICITLY_SHARED_WITHOUT_NAME', index=8, number=8,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CANNOT_UPDATE_CAMPAIGN_BUDGET_TO_EXPLICITLY_SHARED', index=9, number=9,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CANNOT_USE_IMPLICITLY_SHARED_CAMPAIGN_BUDGET_WITH_MULTIPLE_CAMPAIGNS', index=10, number=10,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DUPLICATE_NAME', index=11, number=11,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MONEY_AMOUNT_IN_WRONG_CURRENCY', index=12, number=12,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MONEY_AMOUNT_LESS_THAN_CURRENCY_MINIMUM_CPC', index=13, number=13,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MONEY_AMOUNT_TOO_LARGE', index=14, number=14,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NEGATIVE_MONEY_AMOUNT', index=15, number=15,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NON_MULTIPLE_OF_MINIMUM_CURRENCY_UNIT', index=16, number=16,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=159,
  serialized_end=867,
)
_sym_db.RegisterEnumDescriptor(_CAMPAIGNBUDGETERRORENUM_CAMPAIGNBUDGETERROR)


_CAMPAIGNBUDGETERRORENUM = _descriptor.Descriptor(
  name='CampaignBudgetErrorEnum',
  full_name='google.ads.googleads.v2.errors.CampaignBudgetErrorEnum',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CAMPAIGNBUDGETERRORENUM_CAMPAIGNBUDGETERROR,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=131,
  serialized_end=867,
)

_CAMPAIGNBUDGETERRORENUM_CAMPAIGNBUDGETERROR.containing_type = _CAMPAIGNBUDGETERRORENUM
DESCRIPTOR.message_types_by_name['CampaignBudgetErrorEnum'] = _CAMPAIGNBUDGETERRORENUM
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CampaignBudgetErrorEnum = _reflection.GeneratedProtocolMessageType('CampaignBudgetErrorEnum', (_message.Message,), dict(
  DESCRIPTOR = _CAMPAIGNBUDGETERRORENUM,
  __module__ = 'google.ads.googleads_v2.proto.errors.campaign_budget_error_pb2'
  ,
  __doc__ = """Container for enum describing possible campaign budget errors.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.errors.CampaignBudgetErrorEnum)
  ))
_sym_db.RegisterMessage(CampaignBudgetErrorEnum)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from google.ads.google_ads.v2.proto.services import reach_plan_service_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_reach__plan__service__pb2


class ReachPlanServiceStub(object):
  """Proto file describing the reach plan service.

  Reach Plan Service gives users information about audience size that can
  be reached through advertisement on YouTube. In particular,
  GenerateReachForecast provides estimated number of people of specified
  demographics that can be reached by an ad in a given market by a campaign of
  certain duration with a defined budget.
  """

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.ListPlannableLocations = channel.unary_unary(
        '/google.ads.googleads.v2.services.ReachPlanService/ListPlannableLocations',
        request_serializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_reach__plan__service__pb2.ListPlannableLocationsRequest.SerializeToString,
        response_deserializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_reach__plan__service__pb2.ListPlannableLocationsResponse.FromString,
        )
    self.ListPlannableProducts = channel.unary_unary(
        '/google.ads.googleads.v2.services.ReachPlanService/ListPlannableProducts',
        request_serializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_reach__plan__service__pb2.ListPlannableProductsRequest.SerializeToString,
        response_deserializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_reach__plan__service__pb2.ListPlannableProductsResponse.FromString,
        )
    self.GenerateProductMixIdeas = channel.unary_unary(
        '/google.ads.googleads.v2.services.ReachPlanService/GenerateProductMixIdeas',
        request_serializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_reach__plan__service__pb2.GenerateProductMixIdeasRequest.SerializeToString,
        response_deserializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_reach__plan__service__pb2.GenerateProductMixIdeasResponse.FromString,
        )
    self.GenerateReachForecast = channel.unary_unary(
        '/google.ads.googleads.v2.services.ReachPlanService/GenerateReachForecast',
        request_serializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_reach__plan__service__pb2.GenerateReachForecastRequest.SerializeToString,
        response_deserializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_reach__plan__service__pb2.GenerateReachForecastResponse.FromString,
        )


class ReachPlanServiceServicer(object):
  """Proto file describing the reach plan service.

  Reach Plan Service gives users information about audience size that can
  be reached through advertisement on YouTube. In particular,
  GenerateReachForecast provides estimated number of people of specified
  demographics that can be reached by an ad in a given market by a campaign of
  certain duration with a defined budget.
  """

  def ListPlannableLocations(self, request, context):
    """Returns the list of plannable locations (for example, countries & DMAs).
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def ListPlannableProducts(self, request, context):
    """Returns the list of per-location plannable YouTube ad formats with allowed
    targeting.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def GenerateProductMixIdeas(self, request, context):
    """Generates a product mix ideas given a set of preferences. This method
    helps the advertiser to obtain a good mix of ad formats and budget
    allocations based on its preferences.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def GenerateReachForecast(self, request, context):
    """Generates a reach forecast for a given targeting / product mix.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_ReachPlanServiceServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'ListPlannableLocations': grpc.unary_unary_rpc_method_handler(
          servicer.ListPlannableLocations,
          request_deserializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_reach__plan__service__pb2.ListPlannableLocationsRequest.FromString,
          response_serializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_reach__plan__service__pb2.ListPlannableLocationsResponse.SerializeToString,
      ),
      'ListPlannableProducts': grpc.unary_unary_rpc_method_handler(
          servicer.ListPlannableProducts,
          request_deserializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_reach__plan__service__pb2.ListPlannableProductsRequest.FromString,
          response_serializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_reach__plan__service__pb2.ListPlannableProductsResponse.SerializeToString,
      ),
      'GenerateProductMixIdeas': grpc.unary_unary_rpc_method_handler(
          servicer.GenerateProductMixIdeas,
          request_deserializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_reach__plan__service__pb2.GenerateProductMixIdeasRequest.FromString,
          response_serializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_reach__plan__service__pb2.GenerateProductMixIdeasResponse.SerializeToString,
      ),
      'GenerateReachForecast': grpc.unary_unary_rpc_method_handler(
          servicer.GenerateReachForecast,
          request_deserializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_reach__plan__service__pb2.GenerateReachForecastRequest.FromString,
          response_serializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_reach__plan__service__pb2.GenerateReachForecastResponse.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'google.ads.googleads.v2.services.ReachPlanService', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v2/proto/enums/content_label_type.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v2/proto/enums/content_label_type.proto',
  package='google.ads.googleads.v2.enums',
  syntax='proto3',
  serialized_options=_b('\n!com.google.ads.googleads.v2.enumsB\025ContentLabelTypeProtoP\001ZBgoogle.golang.org/genproto/googleapis/ads/googleads/v2/enums;enums\242\002\003GAA\252\002\035Google.Ads.GoogleAds.V2.Enums\312\002\035Google\\Ads\\GoogleAds\\V2\\Enums\352\002!Google::Ads::GoogleAds::V2::Enums'),
  serialized_pb=_b('\n<google/ads/googleads_v2/proto/enums/content_label_type.proto\x12\x1dgoogle.ads.googleads.v2.enums\x1a\x1cgoogle/api/annotations.proto\"\x80\x03\n\x14\x43ontentLabelTypeEnum\"\xe7\x02\n\x10\x43ontentLabelType\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x0b\n\x07UNKNOWN\x10\x01\x12\x17\n\x13SEXUALLY_SUGGESTIVE\x10\x02\x12\x12\n\x0e\x42\x45LOW_THE_FOLD\x10\x03\x12\x11\n\rPARKED_DOMAIN\x10\x04\x12\x08\n\x04GAME\x10\x05\x12\x0c\n\x08JUVENILE\x10\x06\x12\r\n\tPROFANITY\x10\x07\x12\x0b\n\x07TRAGEDY\x10\x08\x12\t\n\x05VIDEO\x10\t\x12\x15\n\x11VIDEO_RATING_DV_G\x10\n\x12\x16\n\x12VIDEO_RATING_DV_PG\x10\x0b\x12\x15\n\x11VIDEO_RATING_DV_T\x10\x0c\x12\x16\n\x12VIDEO_RATING_DV_MA\x10\r\x12\x17\n\x13VIDEO_NOT_YET_RATED\x10\x0e\x12\x12\n\x0e\x45MBEDDED_VIDEO\x10\x0f\x12\x18\n\x14LIVE_STREAMING_VIDEO\x10\x10\x12\x11\n\rSOCIAL_ISSUES\x10\x11\x42\xea\x01\n!com.google.ads.googleads.v2.enumsB\x15\x43ontentLabelTypeProtoP\x01ZBgoogle.golang.org/genproto/googleapis/ads/googleads/v2/enums;enums\xa2\x02\x03GAA\xaa\x02\x1dGoogle.Ads.GoogleAds.V2.Enums\xca\x02\x1dGoogle\\Ads\\GoogleAds\\V2\\Enums\xea\x02!Google::Ads::GoogleAds::V2::Enumsb\x06proto3')
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,])



_CONTENTLABELTYPEENUM_CONTENTLABELTYPE = _descriptor.EnumDescriptor(
  name='ContentLabelType',
  full_name='google.ads.googleads.v2.enums.ContentLabelTypeEnum.ContentLabelType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SEXUALLY_SUGGESTIVE', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BELOW_THE_FOLD', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PARKED_DOMAIN', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GAME', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='JUVENILE', index=6, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PROFANITY', index=7, number=7,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TRAGEDY', index=8, number=8,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='VIDEO', index=9, number=9,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='VIDEO_RATING_DV_G', index=10, number=10,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='VIDEO_RATING_DV_PG', index=11, number=11,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='VIDEO_RATING_DV_T', index=12, number=12,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='VIDEO_RATING_DV_MA', index=13, number=13,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='VIDEO_NOT_YET_RATED', index=14, number=14,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EMBEDDED_VIDEO', index=15, number=15,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LIVE_STREAMING_VIDEO', index=16, number=16,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SOCIAL_ISSUES', index=17, number=17,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=151,
  serialized_end=510,
)
_sym_db.RegisterEnumDescriptor(_CONTENTLABELTYPEENUM_CONTENTLABELTYPE)


_CONTENTLABELTYPEENUM = _descriptor.Descriptor(
  name='ContentLabelTypeEnum',
  full_name='google.ads.googleads.v2.enums.ContentLabelTypeEnum',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CONTENTLABELTYPEENUM_CONTENTLABELTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=126,
  serialized_end=510,
)

_CONTENTLABELTYPEENUM_CONTENTLABELTYPE.containing_type = _CONTENTLABELTYPEENUM
DESCRIPTOR.message_types_by_name['ContentLabelTypeEnum'] = _CONTENTLABELTYPEENUM
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ContentLabelTypeEnum = _reflection.GeneratedProtocolMessageType('ContentLabelTypeEnum', (_message.Message,), dict(
  DESCRIPTOR = _CONTENTLABELTYPEENUM,
  __module__ = 'google.ads.googleads_v2.proto.enums.content_label_type_pb2'
  ,
  __doc__ = """Container for enum describing content label types in ContentLabel.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.enums.ContentLabelTypeEnum)
  ))
_sym_db.RegisterMessage(ContentLabelTypeEnum)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
